@@ -1,6 +1,9 @@
 package Perinci::Examples::Bin;
 
-our $VERSION = '0.02'; # VERSION
+use 5.010001;
+
+our $DATE = '2014-07-03'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 1;
 # ABSTRACT: Perinci example scripts
@@ -17,12 +20,12 @@ Perinci::Examples::Bin - Perinci example scripts
 
 =head1 VERSION
 
-version 0.02
+This document describes version 0.03 of Perinci::Examples::Bin (from Perl distribution Perinci-Examples-Bin), released on 2014-07-03.
 
 =head1 DESCRIPTION
 
 This distribution contains example scripts in bin/. It is split from
-L<Perinci::Example> so the latter does not need to depend on
+L<Perinci::Examples> so the latter does not need to depend on
 L<Perinci::CmdLine>.
 
 =head1 HOMEPAGE
@@ -47,7 +50,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
